@@ -10,6 +10,7 @@ import multiprocessing
 import time
 import plistlib
 import socket
+import pyping
 
 
 LOGGER = logging.getLogger(__name__)
@@ -88,10 +89,8 @@ def client_is_unreachable(client):
     False == client is not
 
     """
-    host_name = client.host_name
-    ping_response = os.system("ping -c 1 %s" % host_name)
-
-    return ping_response
+    ping_response = pyping.ping(client.ip_address, count=1)
+    return ping_response.ret_code
 
 
 def parse_client_io_data(client, io_data):
